'use strict';
		/**
   * File fonts.customize-controls.js.
   *
   * Theme Customizer handling for font controls.
   */

		(function (wp, data, _, $) {
			var api = wp.customize;

			api.FortyTwoMultiFontControl = api.Control.extend({
				ready: function ready() {
					var _this = this;

					var value = this.setting.get();
					var $familySelect = this.container.find('[data-setting-property="family"]');
					var $weightSelect = this.container.find('[data-setting-property="weight"]');
					var $addButton = this.container.find('button');
					var $fontList = this.container.find('ul');
					
					this.currentFontStack = new api.Value('');
					this.currentFontWeights = new api.Value(['400']);

					this.initializeFontFamilySelect($familySelect);
					this.initializeFontWeightSelect($weightSelect);

					this.currentFontWeights.bind(function () {
						var currentFontWeights = _this.currentFontWeights.get();
						var settingValue = _this.setting.get();

						$weightSelect.selectWoo('destroy');
						$weightSelect.html('');

						_this.initializeFontWeightSelect($weightSelect);

						if (!currentFontWeights.includes('' + settingValue.weight)) {
							$weightSelect.val(currentFontWeights[0]).trigger('change');
						}
					});

					$addButton.on('click', function () {
						_this.addFont($familySelect.val(), $weightSelect.val());
					});

					$fontList.on('click', 'button', function () {
						var $button = $(this);
						var family = $button.data('family');
						var weight = $button.data('weight');
						if (family && weight) {
							_this.removeFont(family, weight);
						}
					});
					
					this.updateFontList(value);
				},

				addFont: function addFont(family, weight) {
					var value = _.clone(this.setting.get());
					var foundFamily = false;
					for (var i = 0; i < value.length; ++i) {
						if (value[i].family == family) {
							foundFamily = true;
							if (value[i].weight.indexOf(weight) == -1) {
								value[i].weight.push(weight);
								value[i].weight.sort();
							}
							break;
						}
					}
					if (!foundFamily) {
						value.push({
							family: family,
							weight: [weight]
						});
					}
					this.setting.set(value);
					this.updateFontList(value);
				},

				removeFont: function removeFont(family, weight) {
					var value = _.clone(this.setting.get());
					
					for (var i = 0; i < value.length; ++i) {
						if (value[i].family == family) {
							var weightIndex = value[i].weight.indexOf(weight);
							if (weightIndex != -1) {
								if (value[i].weight.length == 1) {
									value.splice(i, 1);
								} else {
									value[i].weight.splice(weightIndex, 1);
								}
							}
							break;
						}
					}
					
					this.setting.set(value);
					this.updateFontList(value);
				},

				updateFontList: function updateFontList(value) {
					var $fontList = this.container.find('ul');
					if (value.length) {
						var weightLabels = {};
						for (var i = 0; i < data.fontWeights.length; ++i) {
							weightLabels[data.fontWeights[i].id] = data.fontWeights[i].label;
						}
					
					
						$fontList.find('.customize-control-fonts-none').hide().siblings().remove();
						for (var i = 0; i < value.length; ++i) {
							var fontName = 'Unknown font';
							for (var j = 0; j < data.fontFamilies.length; ++j) {
								if (data.fontFamilies[j].id == value[i].family) {
									fontName = data.fontFamilies[j].label;
								}
							}
						
							var $font = $('<li>').append($('<strong>').text(fontName + ': '));
							var $fontWeights = $('<ol>');
											
							for (var j = 0; j < value[i].weight.length; ++j) {
								$fontWeights.append(
									$('<li>')
										.text(weightLabels[value[i].weight[j]])
										.append($('<button>')
													.attr('type', 'button')
													.data({family: value[i].family, weight: value[i].weight[j]})
													.html('x'))
								);
							}
							$fontList.append($font.append($fontWeights));
						}
					} else {
						$fontList.find('.customize-control-fonts-none').show().siblings().remove();
					}
				},

				initializeFontFamilySelect: function initializeFontFamilySelect($element) {
					var _this2 = this;

					var selectData = {};
					var includedData = {};
					var excludedData = {};
					var settingValue = this.setting.get();

					data.fontFamilyGroups.forEach(function (group) {
						selectData[group.id] = {
							id: group.id,
							text: group.label,
							children: []
						};

						includedData[group.id] = {
							id: group.id,
							text: group.label,
							children: []
						};

						excludedData[group.id] = {
							id: group.id,
							text: group.label,
							children: []
						};
					});

					data.fontFamilies.forEach(function (family) {
						var dataset = {
							id: family.id,
							text: family.label,
							fontStack: family.stackString.replace(/"/g, '\''),
							fontWeights: family.weights
						};

						if (family.api) {
							dataset.fontApi = family.api;
						}

						if (!selectData[family.group]) {
							return;
						}

						selectData[family.group].children.push(dataset);

						if (settingValue.family === family.id) {
							_this2.currentFontStack.set(family.stackString.replace(/"/g, '\''));
							_this2.currentFontWeights.set(family.weights);
						}

						if (settingValue.family === family.id || family.include) {
							includedData[family.group].children.push(dataset);
							return;
						}

						excludedData[family.group].children.push(dataset);
					});

					$element.selectWoo({
						data: Object.values(selectData),
						matcher: function matcher(params, data) {
							var term = $.trim(params.term);
							var regexp = new RegExp(term, 'i');
							var filteredData = {};

							if (!data.id || !data.text || !data.children) {
								return null;
							}

							filteredData.id = data.id;
							filteredData.text = data.text;
							filteredData.children = [];

							if (term.length > 3) {
								filteredData.children = filteredData.children.concat(includedData[data.id].children.filter(function (dataset) {
									return !!dataset.id.match(regexp);
								}));
								filteredData.children = filteredData.children.concat(excludedData[data.id].children.filter(function (dataset) {
									return !!dataset.id.match(regexp);
								}));
							} else {
								filteredData.children = filteredData.children.concat(includedData[data.id].children);
							}

							if (!filteredData.children.length) {
								return null;
							}

							return filteredData;
						},
						templateResult: function templateResult(state) {
							var extraIndicator = '';

							if (!state.id || !state.fontStack) {
								return state.text;
							}

							if (state.fontApi && data.apis[state.fontApi]) {
								extraIndicator += ' <small>(' + data.apis[state.fontApi] + ')</small>';
							}

							return $('<span style="font-family:' + state.fontStack + ';">' + state.text + '</span>' + extraIndicator);
						}
					});

					$element.on('select2:select', function (event) {
						if (!event.params.data.fontStack) {
							return;
						}

						_this2.currentFontStack.set(event.params.data.fontStack);
						_this2.currentFontWeights.set(event.params.data.fontWeights);
					});
				},

				initializeFontWeightSelect: function initializeFontWeightSelect($element) {
					var _this3 = this;

					function getSelectData(currentFontWeights) {
						var selectData = [];

						data.fontWeights.forEach(function (weight) {
							if (!currentFontWeights.includes('' + weight.id)) {
								return;
							}

							selectData.push({
								id: weight.id,
								text: weight.label
							});
						});

						return selectData;
					}

					$element.selectWoo({
						data: getSelectData(this.currentFontWeights.get()),
						templateResult: function templateResult(state) {
							if (!state.id) {
								return state.text;
							}

							return $('<span style="font-family:' + _this3.currentFontStack.get() + ';font-weight:' + state.id + ';">' + state.text + '</span>');
						}
					});
				}
			});

			api.bind('ready', function () {
				api.instance('other_fonts', function (setting) {
					setting.transport = 'postMessage';
				});
				
				api.control.add(new api.FortyTwoMultiFontControl('other_fonts', {
					id: 'other_fonts',
					setting: 'other_fonts',
					section: 'general_fonts',
					label: 'Other Fonts',
					type: 'forty_two_multi_font'
				}));
			});
		})(window.wp, window.themeFontsControlsData, window._, window.jQuery);

		/***/