<?php
/**
 * Forty_Two_Customize_Component_Not_Registered_Exception class
 *
 * @package Forty_Two
 * @license GPL-3.0-or-later
 * @link    https://aspengrovestudios.com/themes/forty-two/
 */

/**
 * Exception thrown when a Customizer component is not registered when it is requested.
 *
 * @since 1.0.0
 */
class Forty_Two_Customize_Component_Not_Registered_Exception extends InvalidArgumentException {

	/**
	 * Creates an exception from a given panel identifier.
	 *
	 * @since 1.0.0
	 *
	 * @param string $id Customizer panel identifier.
	 * @return Forty_Two_Customize_Component_Not_Registered_Exception Exception for the given identifier.
	 */
	public static function from_panel_id( $id ) {
		/* translators: %s: panel identifier */
		$message = sprintf( __( '%s is not a registered Customizer panel.', 'forty-two' ), $id );

		return new self( $message );
	}

	/**
	 * Creates an exception from a given section identifier.
	 *
	 * @since 1.0.0
	 *
	 * @param string $id Customizer section identifier.
	 * @return Forty_Two_Customize_Component_Not_Registered_Exception Exception for the given identifier.
	 */
	public static function from_section_id( $id ) {
		/* translators: %s: section identifier */
		$message = sprintf( __( '%s is not a registered Customizer section.', 'forty-two' ), $id );

		return new self( $message );
	}

	/**
	 * Creates an exception from a given control identifier.
	 *
	 * @since 1.0.0
	 *
	 * @param string $id Customizer control identifier.
	 * @return Forty_Two_Customize_Component_Not_Registered_Exception Exception for the given identifier.
	 */
	public static function from_control_id( $id ) {
		/* translators: %s: control identifier */
		$message = sprintf( __( '%s is not a registered Customizer control.', 'forty-two' ), $id );

		return new self( $message );
	}
}
