<?php
/**
 * Forty_Two_Multi_Font_Customize_Control class
 *
 * @package Forty_Two
 * @license GPL-3.0-or-later
 * @link    https://aspengrovestudios.com/themes/forty-two/
 */
 
/*
This file includes code copied from WordPress by Automattic, licensed under
the GNU General Public License version 2 or higher. Licensed under GNU General
Public License version 3 or higher in this project. See license.txt file in the
Forty Two theme's root directory for license text. File modified by Aspen Grove
Studios, Felix Arntz, and/or Jonathan Hall: 2018, 2019-02-08.
*/

/**
 * Class representing a font Customizer control.
 *
 * @since 1.0.0
 */
class Forty_Two_Multi_Font_Customize_Control extends WP_Customize_Control {

	/**
	 * Control type.
	 *
	 * @var string
	 */
	public $type = 'forty_two_multi_font';

	/**
	 * Enqueues scripts and styles for the control.
	 *
	 * @since 1.0.0
	 */
	public function enqueue() {
		$min = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';

		wp_enqueue_script( 'selectWoo', get_theme_file_uri( "/assets/vendor/selectWoo/dist/js/selectWoo.full{$min}.js" ), array( 'jquery' ), '1.0.2', true );
		wp_enqueue_style( 'selectWoo', get_theme_file_uri( "/assets/vendor/selectWoo/dist/css/selectWoo{$min}.css" ), array(), '1.0.2' );
		wp_add_inline_style( 'selectWoo', '.select2-container.select2-container--open { z-index: 1000000; }' );
	}

	/**
	 * Prevents rendering the control content from PHP, as it iss rendered via JS on load.
	 *
	 * @since 1.0.0
	 */
	public function render_content() {}

	/**
	 * Renders a JS template for the control content.
	 *
	 * @since 1.0.0
	 */
	public function content_template() {
		?>
		<# if ( data.label ) { #>
			<span class="customize-control-title">{{{ data.label }}}</span>
		<# } #>
		<# if ( data.description ) { #>
			<span class="description customize-control-description">{{{ data.description }}}</span>
		<# } #>
		<div class="customize-control-content">
			<ul>
				<li class="customize-control-fonts-none"><?php esc_html_e( 'No other fonts are currently registered.', 'forty-two' ); ?></li>
			</ul>
			<fieldset>
				<legend class="screen-reader-text">{{{ data.label }}}</legend>

				<label for="customize-control-font-family-{{{ data.id }}}"><?php esc_html_e( 'Font Family', 'forty-two' ); ?></label>
				<select {{{ data.inputAttrs }}} id="customize-control-font-family-{{{ data.id }}}" data-setting-property="family" placeholder="<?php esc_attr_e( 'Select Font Family', 'forty-two' ); ?>"></select>

				<label for="customize-control-font-weight-{{{ data.id }}}"><?php esc_html_e( 'Font Weight', 'forty-two' ); ?></label>
				<select {{{ data.inputAttrs }}} id="customize-control-font-weight-{{{ data.id }}}" data-setting-property="weight" placeholder="<?php esc_attr_e( 'Select Font Weight', 'forty-two' ); ?>"></select>
				
				<button type="button" class="buttom-primary"><?php esc_html_e( 'Add Font', 'forty-two' ); ?></button>
			</fieldset>
		</div>
		<?php
	}
}
