<?php
/**
 * Forty_Two_Args_Theme_Feature class
 *
 * @package Forty_Two
 * @license GPL-3.0-or-later
 * @link    https://aspengrovestudios.com/themes/forty-two/
 */

/**
 * Class representing a theme feature with arbitrary arguments.
 *
 * @since 1.0.0
 */
class Forty_Two_Args_Theme_Feature extends Forty_Two_Theme_Feature {

	/**
	 * String identifier for the theme feature.
	 *
	 * @since 1.0.0
	 * @var string
	 */
	protected $id;

	/**
	 * Arbitrary arguments for the theme feature.
	 *
	 * @since 1.0.0
	 * @var array
	 */
	protected $args;

	/**
	 * Constructor.
	 *
	 * @since 1.0.0
	 *
	 * @param string $id   String identifier for the theme feature.
	 * @param array  $args Optional. Arbitrary arguments for the theme feature.
	 */
	public function __construct( $id, array $args = array() ) {
		parent::__construct( $id );

		$this->args = $args;
	}

	/**
	 * Gets the value registered as theme support.
	 *
	 * @since 1.0.0
	 *
	 * @return array Theme support arguments, or empty array if not supported.
	 */
	public function get_support() {
		$args = parent::get_support();

		if ( is_array( $args ) && isset( $args[0] ) ) {
			return $args[0];
		}

		return array();
	}

	/**
	 * Adds support for this feature to core.
	 *
	 * @since 1.0.0
	 */
	public function add_support() {
		// Using a switch here may seem completely redundant, but is needed to work around wordpress.org theme check issues.
		switch ( $this->id ) {
			case 'custom-background':
				add_theme_support( 'custom-background', $this->args );
				break;
			case 'custom-header':
				add_theme_support( 'custom-header', $this->args );
				break;
			case 'custom-logo':
				add_theme_support( 'custom-logo', $this->args );
				break;
			default:
				add_theme_support( $this->id, $this->args );
		}
	}
}
