<?php
/**
 * WP Ajaxify Comments compatibility functions
 *
 * @package Forty_Two
 * @license GPL-3.0-or-later
 * @link    https://aspengrovestudios.com/themes/forty-two/
 */

/**
 * Shows a warning about incompatibility with WP Ajaxify Comments to users that can deactivate plugins.
 *
 * @since 1.0.0
 */
function forty_two_ajaxify_comments_warning() {
	// 'deactivate_plugins' is not available in WordPress < 4.9.
	if ( version_compare( $GLOBALS['wp_version'], '4.9', '<' ) ) {
		if ( ! current_user_can( 'activate_plugins' ) ) {
			return;
		}
	} else {
		if ( ! current_user_can( 'deactivate_plugins' ) ) {
			return;
		}
	}

	?>
	<div class="notice notice-warning">
		<p><?php esc_html_e( 'Forty Two already handles comment form submissions via AJAX out-of-the-box, so the plugin WP Ajaxify Comments conflicts with it and is not necessary. Please deactivate it.', 'forty-two' ); ?></p>
	</div>
	<?php
}
add_action( 'admin_notices', 'forty_two_ajaxify_comments_warning' );
